@@ -108,10 +108,10 @@ short *collect_graphics(short *pagelist)
 #ifndef HAVE_CAIRO
 Boolean transform_graphic(graphicptr gp)
 {
-    int width, height, twidth, theight, rotation;
-    float scale, tscale;
+    int width, height, twidth, theight;
+    float scale, tscale, rotation, crot;
     double cosr, sinr;
-    int x, y, c, s, hw, hh, thw, thh, xorig, yorig, crot, xc, yc;
+    int x, y, c, s, hw, hh, thw, thh, xorig, yorig, xc, yc;
     int screen = DefaultScreen(dpy);
     static GC cmgc = (GC)NULL;
 
@@ -119,8 +119,8 @@ Boolean transform_graphic(graphicptr gp)
     scale = gp->scale * tscale;
     rotation = gp->rotation + UTopRotation();
 
-    if (rotation >= 360) rotation -= 360;
-    else if (rotation < 0) rotation += 360;
+    if (rotation >= 360.0) rotation -= 360.0;
+    else if (rotation < 0.0) rotation += 360.0;
 
     /* Check if the top-level rotation and scale match the	*/
     /* saved target image.  If so, then we're done.		*/
@@ -135,8 +135,8 @@ Boolean transform_graphic(graphicptr gp)
     /* that fits the rotated and scaled image.			*/
 
     crot = rotation;
-    if (crot > 90 && crot < 180) crot = 180 - crot;
-    if (crot > 270 && crot < 360) crot = 360 - crot;
+    if (crot > 90.0 && crot < 180.0) crot = 180.0 - crot;
+    if (crot > 270.0 && crot < 360.0) crot = 360.0 - crot;
     cosr = cos(RADFAC * crot);
     sinr = sin(RADFAC * crot);
     width = gp->source->width * scale;
@@ -183,7 +183,7 @@ Boolean transform_graphic(graphicptr gp)
        return FALSE;
     }
 
-    if (rotation != 0) {
+    if (rotation != 0.0) {
        gp->clipmask = XCreatePixmap(dpy, areawin->window, twidth, theight, 1);
        if (cmgc == (GC)NULL) {
           XGCValues values;
@@ -412,13 +412,13 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
     (*gp)->scale = 1.0;
     (*gp)->position.x = px;
     (*gp)->position.y = py;
-    (*gp)->rotation = 0;
+    (*gp)->rotation = 0.0;
     (*gp)->color = DEFAULTCOLOR;
     (*gp)->passed = NULL;
     (*gp)->source = iptr->image;
 #ifndef HAVE_CAIRO
     (*gp)->target = NULL;
-    (*gp)->trot = 0;
+    (*gp)->trot = 0.0;
     (*gp)->tscale = 0;
     (*gp)->clipmask = (Pixmap)NULL;
 #endif /* HAVE_CAIRO */
@@ -494,13 +494,13 @@ graphicptr gradient_field(objinstptr destinst, int px, int py, int c1, int c2)
     (*gp)->scale = 1.0;
     (*gp)->position.x = px;
     (*gp)->position.y = py;
-    (*gp)->rotation = 0;
+    (*gp)->rotation = 0.0;
     (*gp)->color = DEFAULTCOLOR;
     (*gp)->passed = NULL;
     (*gp)->source = iptr->image;
 #ifndef HAVE_CAIRO
     (*gp)->target = NULL;
-    (*gp)->trot = 0;
+    (*gp)->trot = 0.0;
     (*gp)->tscale = 0;
     (*gp)->clipmask = (Pixmap)NULL;
 #endif /* HAVE_CAIRO */
