@@ -442,7 +442,7 @@ int xctcl_spice(ClientData clientData, Tcl_Interp *interp,
         int objc, Tcl_Obj *CONST objv[])
 {
    int result, idx;
-   char *msg, *eptr;
+   char *msg, *msgin, *eptr;
 
    static char *subCmds[] = {
 	"start", "send", "get", "break", "resume", "status",
@@ -533,20 +533,24 @@ int xctcl_spice(ClientData clientData, Tcl_Interp *interp,
 	 /* method, so we keep control over the output and the	*/
 	 /* state of the simulator.				*/
 
-	 msg = Tcl_GetString(objv[2]);
-	 if (!strncmp(msg, "run", 3) || !strncmp(msg, "resume", 6)) {
+	 msgin = Tcl_GetString(objv[2]);
+	 if (!strncmp(msgin, "run", 3) || !strncmp(msgin, "resume", 6)) {
 	    Tcl_SetResult(interp, "Do not use \"send\" with "
 			"\"run\" or \"resume\"\n", NULL);
 	    return TCL_ERROR;
 	 }
 	 else
-	    send_to_spice(msg);
+	    send_to_spice(msgin);
 
 	 msg = recv_from_spice(interp, EXPECT_PROMPT);
 	 if (*msg == '\0')
 	    return TCL_ERROR;
-	 else
-	    Tcl_SetResult(interp, msg, TCL_STATIC);
+	 else {
+	    char *mp = msg;
+            /* ngspice echos the terminal, so walk past input */
+            while (*mp++ == *msgin++);
+	    Tcl_SetResult(interp, mp, TCL_STATIC);
+         }
 	 break;
 
       case FlushIdx:
@@ -593,6 +597,7 @@ int xctcl_spice(ClientData clientData, Tcl_Interp *interp,
 	 /* the result.	 However, if no index is provided for 	*/
 	 /* the variable, we determine the timestep and set the	*/
 	 /* index accordingly.					*/
+
 	 msg = Tcl_GetString(objv[2]);
 	 if (strchr(msg, '[') != NULL)
 	    sprintf(_STR2, "print %s", msg);
